.. include::  ../README.rst
   :end-before: end_before_documentation

How to Use This Guide
---------------------

After having successfully install ``cobaya_utilities``, you can probably learn most of what you need
from the tutorials listed below

We welcome bug reports, patches, feature requests, and other comments via `the GitHub issue tracker
<https://github.com/xgarrido/cobaya_utilities/issues>`_.


.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   tutorials/chains
   tutorials/fisher
